"use strict";
/*!
 * Paradigm UI Web
 * Copyright (c) 2017 Miracle Devs, Inc
 * Licensed under MIT (https://gitlab.com/miracledevs-paradigm/ui-web-angularjs/blob/master/LICENSE)
 */
Object.defineProperty(exports, "__esModule", { value: true });
var paradigm_ui_web_shared_1 = require("@miracledevs/paradigm-ui-web-shared");
var registrable_1 = require("../decorators/registrable");
var $ = require("jquery");
var DirectiveBase = /** @class */ (function () {
    function DirectiveBase() {
        var _this = this;
        var decorator = this.constructor[registrable_1.registrableMetadataKey];
        if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(decorator)) {
            for (var key in decorator) {
                var destinationKey = (key === "bindings") ? "scope" : key;
                this[destinationKey] = decorator[key];
            }
        }
        this.link = function (s, e, a, c, t) {
            var element = $(e);
            _this.create(s, element, a, c, t);
            s.$on("$destroy", function () { return _this.dispose(s, element, a, c, t); });
        };
    }
    DirectiveBase.prototype.dispose = function (scope, instanceElement, instanceAttributes, controller, transclude) {
        instanceElement.remove();
    };
    DirectiveBase.prototype.call = function (call, success, loading, fail) {
        if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(loading))
            loading(true);
        call()
            .then(function (result) {
            if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(loading))
                loading(false);
            if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(success)) {
                success(result);
            }
        })
            .catch(function (error) {
            if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(loading))
                loading(false);
            if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(fail))
                fail(error);
        });
    };
    DirectiveBase.prototype.getOptions = function (instanceAttributes, optionsParameter) {
        if (paradigm_ui_web_shared_1.StringExtensions.isNullOrWhiteSpace(instanceAttributes[optionsParameter]))
            return null;
        return JSON.parse(instanceAttributes[optionsParameter]);
    };
    DirectiveBase.prototype.tryGetInt = function (options, instanceAttributes, optionFrom, optionTo) {
        optionTo = optionTo || optionFrom;
        if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(instanceAttributes[optionFrom]))
            options[optionTo] = parseInt(instanceAttributes[optionFrom]);
        return options[optionTo];
    };
    DirectiveBase.prototype.tryGetNumber = function (options, instanceAttributes, optionFrom, optionTo) {
        optionTo = optionTo || optionFrom;
        if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(instanceAttributes[optionFrom]))
            options[optionTo] = parseFloat(instanceAttributes[optionFrom]);
        return options[optionTo];
    };
    DirectiveBase.prototype.tryGetDate = function (options, instanceAttributes, optionFrom, optionTo) {
        optionTo = optionTo || optionFrom;
        if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(instanceAttributes[optionFrom]))
            options[optionTo] = new Date(instanceAttributes[optionFrom]);
        return options[optionTo];
    };
    DirectiveBase.prototype.tryGetBoolean = function (options, instanceAttributes, optionFrom, optionTo) {
        optionTo = optionTo || optionFrom;
        if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(instanceAttributes[optionFrom])) {
            var value = instanceAttributes[optionFrom].toLowerCase();
            options[optionTo] = value === "yes" ||
                value === "true" ||
                value === "1";
        }
        return options[optionTo];
    };
    DirectiveBase.prototype.tryGet = function (options, instanceAttributes, optionFrom, optionTo) {
        optionTo = optionTo || optionFrom;
        if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(instanceAttributes[optionFrom]))
            options[optionTo] = instanceAttributes[optionFrom];
        return options[optionTo];
    };
    return DirectiveBase;
}());
exports.DirectiveBase = DirectiveBase;
