"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
/*!
 * Paradigm UI Web
 * Copyright (c) 2017 Miracle Devs, Inc
 * Licensed under MIT (https://gitlab.com/miracledevs-paradigm/ui-web-angularjs/blob/master/LICENSE)
 */
var service_1 = require("../decorators/service");
var base_service_1 = require("./base.service");
var paradigm_ui_web_shared_1 = require("@miracledevs/paradigm-ui-web-shared");
var DateService = /** @class */ (function (_super) {
    tslib_1.__extends(DateService, _super);
    function DateService() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DateService_1 = DateService;
    DateService.prototype.getDate = function (value) {
        if (value instanceof Date)
            return value;
        var date = new Date();
        if (paradigm_ui_web_shared_1.StringExtensions.isString(value))
            date = new Date(value);
        if (paradigm_ui_web_shared_1.ObjectExtensions.isNull(date) || isNaN(date.getTime())) {
            date = paradigm_ui_web_shared_1.DateExtensions.fromIso8601(value);
        }
        return date;
    };
    DateService.prototype.getDateRangeValue = function (value) {
        var oneSecond = 1000;
        var oneMinute = oneSecond * 60;
        var oneHour = oneMinute * 60;
        var oneDay = oneHour * 24;
        var oneYear = 12;
        var now = new Date(Date.now());
        var nowMiliseconds = now.getMilliseconds();
        var nowSeconds = now.getSeconds();
        var nowMinutes = now.getMinutes();
        var nowHours = now.getHours();
        var nowDays = now.getDate();
        var nowMonths = now.getMonth();
        var nowYears = now.getFullYear();
        // var oneSecondAgo = new Date(nowYears, nowMonths, nowDays, nowHours, nowMinutes, nowSeconds - 1, nowMiliseconds);
        var oneMinuteAgo = new Date(nowYears, nowMonths, nowDays, nowHours, nowMinutes - 1, nowSeconds, nowMiliseconds);
        var oneHourAgo = new Date(nowYears, nowMonths, nowDays, nowHours - 1, nowMinutes, nowSeconds, nowMiliseconds);
        var oneDayAgo = new Date(nowYears, nowMonths, nowDays - 1, nowHours, nowMinutes, nowSeconds, nowMiliseconds);
        var oneMonthAgo = new Date(nowYears, nowMonths - 1, nowDays, nowHours, nowMinutes, nowSeconds, nowMiliseconds);
        var oneYearAgo = new Date(nowYears - 1, nowMonths, nowDays, nowHours, nowMinutes, nowSeconds, nowMiliseconds);
        if (paradigm_ui_web_shared_1.ObjectExtensions.isNull(value))
            return new DateRangeValue(0, DateRange.Unknown);
        var date = this.getDate(value);
        var rangeSeconds = Math.floor((now.valueOf() - date.valueOf()) / oneSecond);
        var rangeMinutes = Math.floor((now.valueOf() - date.valueOf()) / oneMinute);
        var rangeHours = Math.floor((now.valueOf() - date.valueOf()) / oneHour);
        var rangeDays = Math.floor((now.valueOf() - date.valueOf()) / oneDay);
        var rangeMonths = this.getMonthDifference(date, now);
        var rangeYears = Math.floor(rangeMonths / oneYear);
        if (date > oneMinuteAgo) {
            return new DateRangeValue(rangeSeconds, DateRange.Seconds);
        }
        else if (date > oneHourAgo && date <= oneMinuteAgo) {
            return new DateRangeValue(rangeMinutes, DateRange.Minutes);
        }
        if (date > oneDayAgo && date <= oneHourAgo) {
            return new DateRangeValue(rangeHours, DateRange.Hours);
        }
        else if (date > oneMonthAgo && date <= oneDayAgo) {
            return new DateRangeValue(rangeDays, DateRange.Days);
        }
        else if (date > oneYearAgo && date <= oneMonthAgo) {
            return new DateRangeValue(rangeMonths, DateRange.Months);
        }
        return new DateRangeValue(rangeYears, DateRange.Years);
    };
    DateService.prototype.getMonthDifference = function (d1, d2) {
        var months;
        months = (d2.getFullYear() - d1.getFullYear()) * 12;
        months -= d1.getMonth();
        months += d2.getMonth();
        return months <= 0 ? 0 : months;
    };
    DateService.factory = function () {
        return new DateService_1();
    };
    DateService = DateService_1 = tslib_1.__decorate([
        service_1.Service({ name: "$pd-dateService" })
    ], DateService);
    return DateService;
    var DateService_1;
}(base_service_1.ServiceBase));
exports.DateService = DateService;
var DateRange;
(function (DateRange) {
    DateRange[DateRange["Unknown"] = 0] = "Unknown";
    DateRange[DateRange["Seconds"] = 1] = "Seconds";
    DateRange[DateRange["Minutes"] = 2] = "Minutes";
    DateRange[DateRange["Hours"] = 3] = "Hours";
    DateRange[DateRange["Days"] = 4] = "Days";
    DateRange[DateRange["Months"] = 5] = "Months";
    DateRange[DateRange["Years"] = 6] = "Years";
})(DateRange = exports.DateRange || (exports.DateRange = {}));
var MonthName;
(function (MonthName) {
    MonthName[MonthName["January"] = 0] = "January";
    MonthName[MonthName["February"] = 1] = "February";
    MonthName[MonthName["March"] = 2] = "March";
    MonthName[MonthName["April"] = 3] = "April";
    MonthName[MonthName["May"] = 4] = "May";
    MonthName[MonthName["June"] = 5] = "June";
    MonthName[MonthName["July"] = 6] = "July";
    MonthName[MonthName["August"] = 7] = "August";
    MonthName[MonthName["September"] = 8] = "September";
    MonthName[MonthName["October"] = 9] = "October";
    MonthName[MonthName["November"] = 10] = "November";
    MonthName[MonthName["December"] = 11] = "December";
})(MonthName = exports.MonthName || (exports.MonthName = {}));
var DayName;
(function (DayName) {
    DayName[DayName["Sunday"] = 0] = "Sunday";
    DayName[DayName["Monday"] = 1] = "Monday";
    DayName[DayName["Tuesday"] = 2] = "Tuesday";
    DayName[DayName["Wednesday"] = 3] = "Wednesday";
    DayName[DayName["Thursday"] = 4] = "Thursday";
    DayName[DayName["Friday"] = 5] = "Friday";
    DayName[DayName["Saturday"] = 6] = "Saturday";
})(DayName = exports.DayName || (exports.DayName = {}));
var DateRangeValue = /** @class */ (function () {
    function DateRangeValue(value, range) {
        this.value = value;
        this.range = range;
    }
    return DateRangeValue;
}());
exports.DateRangeValue = DateRangeValue;
