"use strict";
/*!
 * Paradigm UI Web
 * Copyright (c) 2017 Miracle Devs, Inc
 * Licensed under MIT (https://gitlab.com/miracledevs-paradigm/ui-web-angularjs/blob/master/LICENSE)
 */
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var service_1 = require("../decorators/service");
var base_service_1 = require("./base.service");
var angular_service_1 = require("./angular.service");
var paradigm_ui_web_shared_1 = require("@miracledevs/paradigm-ui-web-shared");
var FileManagementService = /** @class */ (function (_super) {
    tslib_1.__extends(FileManagementService, _super);
    function FileManagementService(timeout) {
        var _this = _super.call(this) || this;
        _this.timeout = timeout;
        return _this;
    }
    FileManagementService_1 = FileManagementService;
    FileManagementService.prototype.read = function (file, completed, progress, error) {
        var _this = this;
        var reader = new FileReader();
        reader.onload = function (e) { return _this.timeout(function () { return completed(file, btoa(e.target["result"])); }); };
        if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(progress))
            reader.onprogress = function (e) {
                if (e.lengthComputable) {
                    var percentLoaded = Math.round((e.loaded / e.total) * 100);
                    progress(percentLoaded);
                }
            };
        if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(error)) {
            reader.onabort = function (e) { return error(_this.getError(e)); };
            reader.onerror = function (e) { return error(_this.getError(e)); };
        }
        reader.readAsBinaryString(file);
    };
    FileManagementService.prototype.download = function (fileName, content) {
        var a = window.document.createElement("a");
        a.href = window.URL.createObjectURL(this.getBlob(fileName, content));
        a.download = fileName;
        document.body.appendChild(a);
        a.click();
        document.body.removeChild(a);
    };
    FileManagementService.prototype.open = function (fileName, content) {
        var blob = this.getBlob(fileName, content);
        if (window.navigator && window.navigator.msSaveOrOpenBlob) {
            window.navigator.msSaveOrOpenBlob(blob, fileName);
        }
        else {
            var url = window.URL.createObjectURL(blob);
            window.open(url);
        }
    };
    FileManagementService.prototype.getBlobUrl = function (fileName, content) {
        return window.URL.createObjectURL(this.getBlob(fileName, content));
    };
    FileManagementService.prototype.getBlob = function (fileName, content64) {
        var content = atob(content64);
        var byteArray = new Uint8Array(content.length);
        for (var i = 0; i < byteArray.length; i++)
            byteArray[i] = content.charCodeAt(i);
        return new Blob([byteArray], { type: paradigm_ui_web_shared_1.fileMimeType.get(fileName) });
    };
    FileManagementService.prototype.getError = function (e) {
        switch (e.target["error"].code) {
            case e.target["error"].NOT_FOUND_ERR:
                return "File not found.";
            case e.target["error"].NOT_READABLE_ERR:
                return "File is not readable.";
            case e.target["error"].ABORT_ERR:
                return "Read operation was aborted.";
            case e.target["error"].SECURITY_ERR:
                return "File is in a locked state.";
            case e.target["error"].ENCODING_ERR:
                return "The file is too long to encode.";
            default:
                return "Can not read the file.";
        }
    };
    FileManagementService.factory = function (timeout) {
        return new FileManagementService_1(timeout);
    };
    FileManagementService = FileManagementService_1 = tslib_1.__decorate([
        service_1.Service({
            name: "$pd-fileManagementService",
            dependencies: [angular_service_1.AngularServices.timeout]
        })
    ], FileManagementService);
    return FileManagementService;
    var FileManagementService_1;
}(base_service_1.ServiceBase));
exports.FileManagementService = FileManagementService;
