"use strict";
/*!
 * Paradigm UI Web
 * Copyright (c) 2017 Miracle Devs, Inc
 * Licensed under MIT (https://gitlab.com/miracledevs-paradigm/ui-web-angularjs/blob/master/LICENSE)
 */
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var base_service_1 = require("./base.service");
var paradigm_ui_web_shared_1 = require("@miracledevs/paradigm-ui-web-shared");
var HttpServiceBase = /** @class */ (function (_super) {
    tslib_1.__extends(HttpServiceBase, _super);
    function HttpServiceBase(http, host) {
        var _this = _super.call(this) || this;
        _this.http = http;
        _this.host = host;
        return _this;
    }
    HttpServiceBase.prototype.get = function (url, parameters) {
        return this.http.get(this.getUrl(url, parameters), { responseType: "json", headers: this.getHeaders() });
    };
    HttpServiceBase.prototype.post = function (url, parameters, body) {
        return this.http.post(this.getUrl(url, parameters), body, { responseType: "json", headers: this.getHeaders() });
    };
    HttpServiceBase.prototype.put = function (url, parameters, body) {
        return this.http.put(this.getUrl(url, parameters), body, { responseType: "json", headers: this.getHeaders() });
    };
    HttpServiceBase.prototype.patch = function (url, parameters, body) {
        return this.http.patch(this.getUrl(url, parameters), body, { responseType: "json", headers: this.getHeaders() });
    };
    HttpServiceBase.prototype.delete = function (url, parameters) {
        return this.http.delete(this.getUrl(url, parameters), { responseType: "json", headers: this.getHeaders() });
    };
    HttpServiceBase.prototype.options = function (url, parameters) {
        throw Error("Http verb not supported.");
    };
    HttpServiceBase.prototype.getStringValue = function (value) {
        if (paradigm_ui_web_shared_1.ObjectExtensions.isNull(value))
            return "";
        if (paradigm_ui_web_shared_1.ObjectExtensions.getTypeName(value) === "Number" ||
            paradigm_ui_web_shared_1.ObjectExtensions.getTypeName(value) === "String" ||
            paradigm_ui_web_shared_1.ObjectExtensions.getTypeName(value) === "Boolean") {
            return value.toString();
        }
        if (paradigm_ui_web_shared_1.ObjectExtensions.getTypeName(value) === "Date") {
            return paradigm_ui_web_shared_1.DateExtensions.formatUTC(value, "yyyy-MM-ddThh:mm:ss.fff");
        }
        return "";
    };
    HttpServiceBase.prototype.getUrl = function (url, params) {
        if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(params)) {
            for (var key in params) {
                if (params.hasOwnProperty(key)) {
                    url = url.replace("{" + key + "}", this.getStringValue(params[key]));
                }
            }
        }
        return "" + this.host + url;
    };
    HttpServiceBase.prototype.getHeaders = function () {
        return { "Content-Type": "application/json; charset=utf-8" };
    };
    return HttpServiceBase;
}(base_service_1.ServiceBase));
exports.HttpServiceBase = HttpServiceBase;
